﻿using Bmp.Core.Common.EventBus;
using Microsoft.Extensions.Logging;

namespace Bmp.Core.Common.Logging;

public class LoggingIntoEventBus : ILoggerProvider
{
    public IEventBus? EventBus { get; set; }

    public void Dispose()
    {
    }

    public ILogger CreateLogger(string categoryName)
    {
        return new LoggingIntoEventBusLogger(categoryName, this);
    }

    private class LoggingIntoEventBusLogger : ILogger
    {
        private readonly string _categoryName;
        private readonly LoggingIntoEventBus _owner;


        public LoggingIntoEventBusLogger(string categoryName, LoggingIntoEventBus owner)
        {
            _categoryName = categoryName;
            _owner = owner;
        }

        public IDisposable? BeginScope<TState>(TState state) where TState : notnull => default;

        public bool IsEnabled(LogLevel logLevel) => true;

        public void Log<TState>(LogLevel logLevel, EventId eventId, TState state, Exception? exception, Func<TState, Exception?, string> formatter)
        {
            if (_owner.EventBus == null) return;

            var content = Convert.ToString(state);

            if (exception != null)
            {
                content = $"{content} {exception}";
            }

            var formatted = $"[{DateTime.Now:dd HH:mm:ss}] {_categoryName} {content}";
            _owner.EventBus.Publish(new LoggingEvent(logLevel, _categoryName, formatted));
        }
    }
}