﻿using NAudio.CoreAudioApi;
using NAudio.Wave;
using AsioOut = Bmp.Core.Lite.Playback.Outputs.NAudioASIO.AsioOut;

namespace Bmp.Core.Lite.Playback.Outputs
{
    public static class OutputDeviceProvider
    {
        public static IReadOnlyCollection<IOutputDeviceInfo> GetAllSupportedDevices()
        {
            var list = new List<IOutputDeviceInfo>();

            foreach (var asioDriverName in AsioOut.GetDriverNames())
            {
                list.Add(new AsioOutput(asioDriverName));
            }

            foreach (var audioEndPoint in new MMDeviceEnumerator().EnumerateAudioEndPoints(DataFlow.Render, DeviceState.Active))
            {
                list.Add(new WasapiOutput(audioEndPoint, false, false));
                list.Add(new WasapiOutput(audioEndPoint, true, false));
                list.Add(new WasapiOutput(audioEndPoint, false, true));
                list.Add(new WasapiOutput(audioEndPoint, true, true));
            }

            foreach (var directSoundDeviceInfo in DirectSoundOut.Devices)
            {
                list.Add(new DirectSoundOutput(directSoundDeviceInfo));
            }

            return list.ToArray();
        }

        public static IWavePlayer CreateWavePlayer(IOutputDeviceInfo output, bool requireDsdNative = false)
        {
            if (requireDsdNative)
            {
                if (output is AsioOutput == false) throw new ArgumentException("native dsd only support ASIO");
            }

            switch (output)
            {
                case AsioOutput ao:
                    var wavePlayer = new AsioOut(ao.DriverName);
                    if (requireDsdNative) wavePlayer.SetNativeDsd();
                    return wavePlayer;
                case WasapiOutput wasapi: return new WasapiOut(wasapi.AudioEndPoint, wasapi.IsExclude ? AudioClientShareMode.Exclusive : AudioClientShareMode.Shared, wasapi.IsUseEvent, wasapi.Latency);
                case DirectSoundOutput ds: return new DirectSoundOut(ds.DeviceInfo.Guid, ds.Latency);
                default: throw new ArgumentOutOfRangeException(nameof(output));
            }
        }
    }
}
