﻿using NAudio.CoreAudioApi;

namespace Bmp.Core.Lite.Playback.Outputs;

public class WasapiOutput : IOutputDeviceInfo
{
    public string Id => ToString();

    public override string ToString()
    {
        var lstFeature = new List<string>(2);
        if (IsExclude) lstFeature.Add("Exclude");
        if (IsUseEvent) lstFeature.Add("UseEvent");

        return $"{Type}|{(lstFeature.Any() ? $"{string.Join("|", lstFeature)}" : "")}: {AudioEndPoint.ID}";
    }

    public string DisplayName
    {
        get
        {
            var lstFeature = new List<string>(2);
            if (IsExclude) lstFeature.Add("独占");
            if (IsUseEvent) lstFeature.Add("事件");

            return $"{Type}{(lstFeature.Any() ? $"({string.Join("|", lstFeature)})" : "")}: {AudioEndPoint.DeviceFriendlyName}";
        }
    }

    public WasapiOutput(MMDevice audioEndPoint, bool isExclude, bool isUseEvent)
    {
        AudioEndPoint = audioEndPoint;
        IsExclude = isExclude;
        IsUseEvent = isUseEvent;
    }

    public MMDevice AudioEndPoint { get; }
    public bool IsExclude { get; }
    public bool IsUseEvent { get; }

    public OutputType Type => OutputType.WASAPI;

    public bool HasControlPanel => false;

    public void ShowControlPanel() => throw new NotSupportedException();

    public bool CanSetLatency => true;
    public int Latency { get; set; } = 50;
}
