using System.Runtime.InteropServices;

namespace Bmp.Core.FFMpeg.CsCorePorts.FFMpegWrap;

internal sealed class FfmpegStream : IDisposable
{
    private readonly Stream _stream;

    public AvioContext AvioContext { get; private set; }

    public FfmpegStream(Stream stream) : this(stream, true)
    {
    }

    public FfmpegStream(Stream stream, bool allowWrite)
    {
        if (stream == null)
            throw new ArgumentNullException("stream");
        if (!stream.CanRead)
            throw new ArgumentException("Stream is not readable.", "stream");

        _stream = stream;

        AvioContext = new AvioContext(ReadDataCallback,
            stream.CanSeek ? new FfmpegCalls.AvioSeek(SeekCallback) : null,
            stream.CanWrite && allowWrite ? new FfmpegCalls.AvioWriteData(WriteDataCallback) : null);
    }

    private long SeekCallback(nint opaque, long offset, FfmpegCalls.SeekFlags whence)
    {
        if ((whence & FfmpegCalls.SeekFlags.SeekSize) == FfmpegCalls.SeekFlags.SeekSize)
            return _stream.Length;

        SeekOrigin origin;
        if ((whence & FfmpegCalls.SeekFlags.SeekSet) == FfmpegCalls.SeekFlags.SeekSet)
            origin = SeekOrigin.Begin;
        else if ((whence & FfmpegCalls.SeekFlags.SeekCur) == FfmpegCalls.SeekFlags.SeekCur)
            origin = SeekOrigin.Current;
        else if ((whence & FfmpegCalls.SeekFlags.SeekEnd) == FfmpegCalls.SeekFlags.SeekEnd)
            origin = SeekOrigin.End;
        else
            return -1;
        try
        {
            return _stream.Seek(offset, origin);
        }
        catch (Exception)
        {
            return -1;
        }
    }

    private int WriteDataCallback(nint opaque, nint buffer, int bufferSize)
    {
        var managedBuffer = new byte[bufferSize];

        Marshal.Copy(buffer, managedBuffer, 0, bufferSize);
        _stream.Write(managedBuffer, 0, bufferSize);

        return bufferSize;
    }

    private int ReadDataCallback(nint opaque, nint buffer, int bufferSize)
    {
        var managedBuffer = new byte[bufferSize];
        var read = 0;
        while (read < bufferSize)
        {
            var read0 = _stream.Read(managedBuffer, read, bufferSize - read);
            read += read0;
            if (read0 == 0)
                break;
        }

        read = Math.Min(read, bufferSize);
        Marshal.Copy(managedBuffer, 0, buffer, Math.Min(read, bufferSize));

        return read;
    }

    public void Dispose()
    {
        GC.SuppressFinalize(this);

        if (AvioContext != null)
        {
            AvioContext.Dispose();
            AvioContext = null;
        }
    }

    ~FfmpegStream()
    {
        Dispose();
    }
}