﻿using System;
using System.IO;
using System.Runtime.InteropServices;

namespace Bmp.Core.FFMpeg.CsCorePorts.FFMpegWrap.Interops;

internal static class InteropHelper
{
    // ReSharper disable once InconsistentNaming
    public const string LD_LIBRARY_PATH = "LD_LIBRARY_PATH";

    public static void RegisterLibrariesSearchPath(string path)
    {
        if (!Directory.Exists(path))
        {
            var directory = FfmpegUtils.FindFfmpegDirectory(Environment.OSVersion.Platform);
            if (directory != null)
                path = directory.FullName;
        }

        switch (Environment.OSVersion.Platform)
        {
            case PlatformID.Win32NT:
            case PlatformID.Win32S:
            case PlatformID.Win32Windows:
                SetDllDirectory(path);
                break;
            case PlatformID.Unix:
            case PlatformID.MacOSX:
                var currentValue = Environment.GetEnvironmentVariable(LD_LIBRARY_PATH);
                if (string.IsNullOrEmpty(currentValue) == false && currentValue.Contains(path) == false)
                {
                    var newValue = currentValue + Path.PathSeparator + path;
                    Environment.SetEnvironmentVariable(LD_LIBRARY_PATH, newValue);
                }
                break;
        }
    }

    [DllImport("kernel32", SetLastError = true)]
    private static extern bool SetDllDirectory(string lpPathName);
}