﻿using Bmp.Core.FFMpeg.CsCorePorts;
using Bmp.Core.FFMpeg.CsCorePorts.FFMpegWrap;
using Bmp.Core.Lite.Metadata;
using Bmp.Core.Lite.Playback.Inputs;
using NAudio.Wave;
using WaveFormat = NAudio.Wave.WaveFormat;

namespace Bmp.Core.Playback.Inputs;

public class FFMPEGAudioStream : WaveStream, IHaveBitPerRawSample, IHaveMetaData, IHaveDecoderInfo
{
    string IHaveDecoderInfo.DecoderName => "FFMPEG";
    string? IHaveDecoderInfo.FileFormat => _ffmpegDecoder?.FileFormat;
    MetaDataWrap IHaveMetaData.MetaData => new() { RawTags = _ffmpegDecoder?.Metadata, Duration = TotalTime };

    public int? BitPerRawSample => _ffmpegDecoder?.BitPerRawSample;

    private readonly FfmpegDecoder? _ffmpegDecoder;

    public override WaveFormat? WaveFormat { get; }

    public override long Length => _ffmpegDecoder?.Length ?? 0;

    public override long Position
    {
        get => _ffmpegDecoder?.Position ?? 0;
        set
        {
            if (null == _ffmpegDecoder) return;
            _ffmpegDecoder.Position = value;
        }
    }

    public FFMPEGAudioStream(string filename)
    {
        _ffmpegDecoder = new FfmpegDecoder(filename);

        if (null == _ffmpegDecoder) return;

        var sampleRate = _ffmpegDecoder.WaveFormat.SampleRate;
        var bitsPerSample = _ffmpegDecoder.WaveFormat.BitsPerSample;
        var channels = _ffmpegDecoder.WaveFormat.Channels;
        var blockAlign = _ffmpegDecoder.WaveFormat.BlockAlign;

        var bytesPerSecond = _ffmpegDecoder.StreamBitPerSecond != null && _ffmpegDecoder.StreamBitPerSecond != 0
            ? _ffmpegDecoder.StreamBitPerSecond.Value
            : _ffmpegDecoder.FileBitPerSecond != null && _ffmpegDecoder.FileBitPerSecond != 0 ? _ffmpegDecoder.FileBitPerSecond.Value
            : _ffmpegDecoder.WaveFormat.BytesPerSecond;

        WaveFormat = WaveFormat.CreateCustomFormat(_ffmpegDecoder.WaveFormat.WaveFormatTag switch
        {
            AudioEncoding.Pcm => WaveFormatEncoding.Pcm,
            AudioEncoding.IeeeFloat => WaveFormatEncoding.IeeeFloat,
            _ => WaveFormatEncoding.Unknown
        }, sampleRate, channels, (int)(bytesPerSecond / 8), blockAlign, bitsPerSample);
    }

    public FFMPEGAudioStream(Stream stream)
    {
        _ffmpegDecoder = new FfmpegDecoder(stream);

        if (null == _ffmpegDecoder) return;
        var sampleRate = _ffmpegDecoder.WaveFormat.SampleRate;
        var bitsPerSample = _ffmpegDecoder.WaveFormat.BitsPerSample;
        var channels = _ffmpegDecoder.WaveFormat.Channels;
        WaveFormat = new WaveFormat(sampleRate, bitsPerSample, channels);
    }

    //fill pcm data to buffer
    public override int Read(byte[] buffer, int offset, int count)
    {
        if (null == _ffmpegDecoder) return 0;
        var tempBuf = new byte[count];
        count = _ffmpegDecoder.Read(tempBuf, 0, tempBuf.Length);

        Buffer.BlockCopy(tempBuf, 0, buffer, 0, count);
        return count;
    }

    protected override void Dispose(bool disposing)
    {
        _ffmpegDecoder?.Dispose();
    }
}
